@@ -8,17 +8,12 @@ import shutil
 import subprocess
 import sys
 import sysconfig
+from importlib import metadata
 from pathlib import Path
+from typing import Any, Literal, overload
 
 import virtualenv as _virtualenv
 
-if sys.version_info < (3, 8):
-    import importlib_metadata as metadata
-    from typing_extensions import Literal, overload
-else:
-    from importlib import metadata
-    from typing import Literal, overload
-
 if sys.version_info < (3, 11):
     import tomli as tomllib
 else:
@@ -27,10 +22,13 @@ else:
 
 import pytest
 from packaging.requirements import Requirement
+from packaging.version import Version
 
 DIR = Path(__file__).parent.resolve()
 BASE = DIR.parent
 
+VIRTUALENV_VERSION = Version(metadata.version("virtualenv"))
+
 
 @pytest.fixture(scope="session")
 def pep518_wheelhouse(tmp_path_factory: pytest.TempPathFactory) -> Path:
@@ -44,7 +42,7 @@ def pep518_wheelhouse(tmp_path_factory: pytest.TempPathFactory) -> Path:
             "wheel",
             "--wheel-dir",
             str(wheelhouse),
-            f"{BASE}[pyproject]",
+            f"{BASE}",
         ],
         check=True,
     )
@@ -52,7 +50,7 @@ def pep518_wheelhouse(tmp_path_factory: pytest.TempPathFactory) -> Path:
         "build",
         "cython",
         "hatchling",
-        "pip>=23",
+        "pip",
         "pybind11",
         "setuptools",
         "virtualenv",
@@ -83,7 +81,9 @@ def pep518_wheelhouse(tmp_path_factory: pytest.TempPathFactory) -> Path:
 
 class VEnv:
     def __init__(self, env_dir: Path, *, wheelhouse: Path | None = None) -> None:
-        cmd = [str(env_dir), "--no-setuptools", "--no-wheel", "--activators", ""]
+        cmd = [str(env_dir), "--no-setuptools", "--activators", ""]
+        if Version("20.31.0") > VIRTUALENV_VERSION:
+            cmd.append("--no-wheel")
         result = _virtualenv.cli_run(cmd, setup_logging=False)
         self.wheelhouse = wheelhouse
         self.executable = Path(result.creator.exe)
@@ -96,12 +96,10 @@ class VEnv:
         )
 
     @overload
-    def run(self, *args: str, capture: Literal[True]) -> str:
-        ...
+    def run(self, *args: str, capture: Literal[True]) -> str: ...
 
     @overload
-    def run(self, *args: str, capture: Literal[False] = ...) -> None:
-        ...
+    def run(self, *args: str, capture: Literal[False] = ...) -> None: ...
 
     def run(self, *args: str, capture: bool = False) -> str | None:
         __tracebackhide__ = True
@@ -156,13 +154,13 @@ class VEnv:
         self.module("pip", "install", *isolated_flags, *args)
 
 
-@pytest.fixture()
+@pytest.fixture
 def isolated(tmp_path: Path, pep518_wheelhouse: Path) -> VEnv:
     path = tmp_path / "venv"
     return VEnv(path, wheelhouse=pep518_wheelhouse)
 
 
-@pytest.fixture()
+@pytest.fixture
 def virtualenv(tmp_path: Path) -> VEnv:
     path = tmp_path / "venv"
     return VEnv(path)
@@ -199,27 +197,35 @@ def process_package(
     package_dir = tmp_path / "pkg"
     shutil.copytree(DIR / "packages" / package.name, package_dir)
     monkeypatch.chdir(package_dir)
-    # Just in case this gets littered into the source tree, clear it out
-    if Path("dist").is_dir():
-        shutil.rmtree("dist")
 
 
-@pytest.fixture()
+@pytest.fixture
 def package_simple_pyproject_ext(
     tmp_path: Path, monkeypatch: pytest.MonkeyPatch
 ) -> PackageInfo:
     package = PackageInfo(
         "simple_pyproject_ext",
-        "6c5bb5f1b6c44f3aab37fc8f768004f644c24001ad0304759a69b754ca6ad46d",
-        "ba13e4195ae6333459412bc802ba8c02c231cf1c5ee143f6a3392786d80a49b4",
-        "f1a6050eae910de7cd86830ba97af5e74ff953f9acc2adab47aa9cdf2a3eca91",
-        "b861db81fd1de6dee4a0d6574af27af54424fbccce12b018644d1db136f218ac",
+        "71b4e95854ef8d04886758d24d18fe55ebe63648310acf58c7423387cca73508",
+        "ed930179fbf5adc2e71a64a6f9686c61fdcce477c85bc94dd51598641be886a7",
+        "0178462b64b4eb9c41ae70eb413a9cc111c340e431b240af1b218fe81b0c2ecb",
+        "de79895a9d5c2112257715214ab419d3635e841716655e8a55390e5d52445819",
     )
     process_package(package, tmp_path, monkeypatch)
     return package
 
 
-@pytest.fixture()
+@pytest.fixture
+def package_simple_pyproject_script_with_flags(
+    tmp_path: Path, monkeypatch: pytest.MonkeyPatch
+) -> PackageInfo:
+    package = PackageInfo(
+        "simple_pyproject_script_with_flags",
+    )
+    process_package(package, tmp_path, monkeypatch)
+    return package
+
+
+@pytest.fixture
 def package_simple_pyproject_source_dir(
     tmp_path: Path, monkeypatch: pytest.MonkeyPatch
 ) -> PackageInfo:
@@ -230,7 +236,7 @@ def package_simple_pyproject_source_dir(
     return package
 
 
-@pytest.fixture()
+@pytest.fixture
 def package_simple_setuptools_ext(
     tmp_path: Path, monkeypatch: pytest.MonkeyPatch
 ) -> PackageInfo:
@@ -239,7 +245,16 @@ def package_simple_setuptools_ext(
     return package
 
 
-@pytest.fixture()
+@pytest.fixture
+def package_toml_setuptools_ext(
+    tmp_path: Path, monkeypatch: pytest.MonkeyPatch
+) -> PackageInfo:
+    package = PackageInfo("toml_setuptools_ext")
+    process_package(package, tmp_path, monkeypatch)
+    return package
+
+
+@pytest.fixture
 def package_mixed_setuptools(
     tmp_path: Path, monkeypatch: pytest.MonkeyPatch
 ) -> PackageInfo:
@@ -248,7 +263,7 @@ def package_mixed_setuptools(
     return package
 
 
-@pytest.fixture()
+@pytest.fixture
 def package_filepath_pure(
     tmp_path: Path, monkeypatch: pytest.MonkeyPatch
 ) -> PackageInfo:
@@ -257,7 +272,7 @@ def package_filepath_pure(
     return package
 
 
-@pytest.fixture()
+@pytest.fixture
 def package_dynamic_metadata(
     tmp_path: Path, monkeypatch: pytest.MonkeyPatch
 ) -> PackageInfo:
@@ -266,7 +281,14 @@ def package_dynamic_metadata(
     return package
 
 
-@pytest.fixture()
+@pytest.fixture
+def package_hatchling(tmp_path: Path, monkeypatch: pytest.MonkeyPatch) -> PackageInfo:
+    package = PackageInfo("hatchling")
+    process_package(package, tmp_path, monkeypatch)
+    return package
+
+
+@pytest.fixture
 def package_simplest_c(tmp_path: Path, monkeypatch: pytest.MonkeyPatch) -> PackageInfo:
     package = PackageInfo(
         "simplest_c",
@@ -275,7 +297,7 @@ def package_simplest_c(tmp_path: Path, monkeypatch: pytest.MonkeyPatch) -> Packa
     return package
 
 
-@pytest.fixture()
+@pytest.fixture
 def navigate_editable(tmp_path: Path, monkeypatch: pytest.MonkeyPatch) -> PackageInfo:
     package = PackageInfo(
         "navigate_editable",
@@ -284,7 +306,16 @@ def navigate_editable(tmp_path: Path, monkeypatch: pytest.MonkeyPatch) -> Packag
     return package
 
 
-@pytest.fixture()
+@pytest.fixture
+def broken_fallback(tmp_path: Path, monkeypatch: pytest.MonkeyPatch) -> PackageInfo:
+    package = PackageInfo(
+        "broken_fallback",
+    )
+    process_package(package, tmp_path, monkeypatch)
+    return package
+
+
+@pytest.fixture
 def package_sdist_config(
     tmp_path: Path, monkeypatch: pytest.MonkeyPatch
 ) -> PackageInfo:
@@ -295,7 +326,7 @@ def package_sdist_config(
     return package
 
 
-@pytest.fixture()
+@pytest.fixture
 def package_simple_purelib_package(
     tmp_path: Path, monkeypatch: pytest.MonkeyPatch
 ) -> PackageInfo:
@@ -306,6 +337,43 @@ def package_simple_purelib_package(
     return package
 
 
+@pytest.fixture
+def package_pep639_pure(tmp_path: Path, monkeypatch: pytest.MonkeyPatch) -> PackageInfo:
+    package = PackageInfo(
+        "pep639_pure",
+    )
+    process_package(package, tmp_path, monkeypatch)
+    return package
+
+
+def which_mock(name: str) -> str | None:
+    if name in {"ninja", "ninja-build", "cmake3", "samu", "gmake", "make"}:
+        return None
+    if name == "cmake":
+        return "cmake/path"
+    return None
+
+
+@pytest.fixture
+def protect_get_requires(fp, monkeypatch):
+    """
+    Protect get_requires from actually calling anything variable during tests.
+    """
+    # This needs to be passed due to packaging.tags 22 extra checks if macos 10.16 is reported
+    fp.pass_command([sys.executable, fp.any()])
+    monkeypatch.setattr(shutil, "which", which_mock)
+    monkeypatch.delenv("CMAKE_GENERATOR", raising=False)
+
+    orig_find_spec = importlib.util.find_spec
+
+    def find_spec(name: str, package: str | None = None) -> Any:
+        if name in {"cmake", "ninja"}:
+            return None
+        return orig_find_spec(name, package)
+
+    monkeypatch.setattr(importlib.util, "find_spec", find_spec)
+
+
 def pytest_collection_modifyitems(items: list[pytest.Item]) -> None:
     for item in items:
         # Ensure all tests using virtualenv are marked as such
